@@ -8,8 +8,6 @@ from typing import TYPE_CHECKING, Any, Callable, Generic, Protocol, TypeVar, ove
 if TYPE_CHECKING:
     from typing_extensions import Self
 
-EllipsisType = type(...)
-
 T = TypeVar("T")
 
 Statv_T = TypeVar("Statv_T", bound="Statv", contravariant=True)
@@ -28,7 +26,7 @@ class UpdateMonitor(Protocol[Statv_T, T]):
 class Stats(Generic[T]):
     id: str
 
-    default: T | EllipsisType = ...
+    default: T | ellipsis = ...
     default_factory: Callable[[], T] | None = None
 
     _validator: StatsValidator[T] | None
@@ -47,7 +45,7 @@ class Stats(Generic[T]):
         self._validator = validator
 
     @overload
-    def __get__(self, instance: None, owner: None) -> Stats:
+    def __get__(self, instance: None, owner: type[Statv]) -> Self:
         ...
 
     @overload
@@ -95,6 +93,7 @@ class Statv:
     def __init__(self, *, init_stats: dict[str, Any] | None = None):
         self._waiters = deque()
         self._stats = {}
+        self._monitors = {}
 
         for stat_define in self.defined_stats():
             if stat_define.default is not ...:
@@ -121,13 +120,13 @@ class Statv:
     def available(self) -> bool:
         return True
 
-    def update_multi(self, mapping: dict[Stats[T], T]) -> None:
+    def update_multi(self, mapping: dict[Stats[Any], Any]) -> None:
         stats = self.defined_stats()
         if not all(isinstance(k, Stats) and k in stats for k in mapping):
             raise TypeError(f"invalid ownership of Stats definition for {self.__class__.__name__}")
 
         for stat, value in mapping.items():
-            past_value: T = self._stats[stat.id]
+            past_value = self._stats[stat.id]
             if stat._validator:
                 value = stat._validator(stat, past_value, value)
             if past_value != value:
